set opt(tr)     "lan-csma.tr"
set opt(namtr)	"lan-csma.nam"
set opt(seed)	0
set opt(stop)	10
set opt(node)	8

set opt(qsize)	100
set opt(bw)     10Mb
set opt(delay)	1ms
set opt(ll)     LL
set opt(ifq)	Queue/DropTail
set opt(mac)	Mac/802_3
set opt(chan)	Channel
set opt(mtrace)	true
set opt(donam)  false

# Define -donam on the command line to execute NAM after the simulation
# is over

proc getopt {argc argv} {
	global opt

	set count_input 0
	
	for {set i 0} {$i < $argc} {incr i} {
		set arg [lindex $argv $i]
		if {[string range $arg 0 0] != "-"} continue

		set name [string range $arg 1 end]
		
		if { $name == "donam" } {
			set opt(donam) true
		}
	}
}

proc finish {} {
	global ns opt trfd namtrfd

	$ns flush-trace
	close $trfd
	if { $opt(donam) == true } {
		close $namtrfd
		exec nam $opt(namtr) &
	}

	exit 0
}


proc create-trace {} {
	global ns opt trfd namtrfd

	set trfd [open $opt(tr) w]
	$ns trace-all $trfd
	
	if { $opt(donam) == true } {
		set namtrfd [open $opt(namtr) w]
		$ns namtrace-all $namtrfd
	}
}


proc create-topology {} {
	global ns opt
	global lan node source node0

	set num $opt(node)
	for {set i 0} {$i < $num} {incr i} {
		set node($i) [$ns node]
		lappend nodelist $node($i)
	}

	set node0 [$ns node]

	set lan [$ns newLan $nodelist $opt(bw) $opt(delay) \
			-llType $opt(ll) -ifqType $opt(ifq) \
			-macType $opt(mac) -chanType $opt(chan) -mactrace $opt(mtrace)]

	
	$ns duplex-link $node0 $node(0) 10Mb 1ms DropTail

	$ns duplex-link-op $node0 $node(0) orient right

	$node(2) color green
	$node(5) color green
	$node(3) color red
	$node(6) color red
	$node(1) color blue
	$node(7) color blue

}

## MAIN ##

getopt $argc $argv

set ns [new Simulator]
ns-random 0
create-trace

$ns color 1 blue
$ns color 2 green
$ns color 3 red

create-topology

set udp1 [new Agent/UDP]
set udp2 [new Agent/UDP]
set udp3 [new Agent/UDP]
set null1 [new Agent/Null]
set null2 [new Agent/Null]
set null3 [new Agent/Null]

$ns attach-agent $node(1) $udp1
$ns attach-agent $node(7) $null1

$ns attach-agent $node(2) $udp2
$ns attach-agent $node(5) $null2

$ns attach-agent $node(3) $udp3
$ns attach-agent $node(6) $null3

$udp1 set fid_ 1
$udp2 set fid_ 2
$udp3 set fid_ 3

set cbr1 [new Application/Traffic/CBR]
set cbr2 [new Application/Traffic/CBR]
set cbr3 [new Application/Traffic/CBR]

$cbr1 set packetSize_ 200
$cbr2 set packetSize_ 200
$cbr3 set packetSize_ 200
$cbr1 set interval_ 0.002
$cbr2 set interval_ 0.002
$cbr3 set interval_ 0.002
$cbr1 attach-agent $udp1
$cbr2 attach-agent $udp2
$cbr3 attach-agent $udp3

$ns connect $udp1 $null1
$ns connect $udp2 $null2
$ns connect $udp3 $null3

$ns at 0.5 "$cbr1 start"
$ns at 0.5 "$cbr2 start"
$ns at 0.5 "$cbr3 start"

$ns at 10.0 "$cbr1 stop"
$ns at 10.0 "$cbr2 stop"
$ns at 10.0 "$cbr3 stop"

$ns at $opt(stop) "finish"
$ns run
